Generic
=======

.. automodule:: biobroker.generic
   :members:
   :undoc-members:
   :show-inheritance:

Pydantic models
---------------
.. automodule:: biobroker.generic.pydantic_model
    :members: StructuredDataModel, BiosampleGeneralModel

Exceptions
----------

.. automodule:: biobroker.generic.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

Logger
------

.. automodule:: biobroker.generic.logger
   :members:
   :undoc-members:
   :show-inheritance:

Utilities
---------

.. automodule:: biobroker.generic.utilities
   :members:
   :undoc-members:
   :show-inheritance:
